#!/sw/bin/perl -w

###############################################################################
##                                                                           ##
##    Copyright (c) 1999 by Steffen Beyer.                                   ##
##    All rights reserved.                                                   ##
##                                                                           ##
##    Version 1.0 written 14-Oct-1999 by Steffen Beyer.                      ##
##                                                                           ##
###############################################################################

use strict;
use MIME::Parser;

sub writelog
{
    my($line);

    foreach $line (@_)
    {
        $line =~ s!\s+$!!;
        print STDERR "$line\n";
    }
}

sub open_mime
{
    my($path) = shift;
    my($file,$parser,$entity);
    my(@err);

    foreach $file (map( glob($_), @_ ))
    {
        unless (-f $file)
        {
            @err = ( "Die Datei '$file' ist nicht vorhanden!" );
            &writelog( @err );
            next;
        }
        @err = ( "Die Datei '$file' wurde abgelehnt." );
        unless (-s $file)
        {
            push( @err,
                  "Grund: Die Datei ist leer." );
            &writelog( $file );
            next;
        }
        $parser = MIME::Parser->new();
        $parser->output_dir( $path );
        $parser->output_prefix( 'mimepart' );
        unless (open(MAIL, "<$file"))
        {
            @err = ( "Kann Datei '$file' nicht oeffnen!", "Grund: $!" );
            &writelog( $file );
            next;
        }
        eval { $entity = $parser->read( \*MAIL ); };
        unless (($@ eq '') && (defined $entity) && (ref $entity))
        {
            if ($@)
            {
                @err = ( "Beim Parsen der Mail trat ein Fehler auf.",
                         "Grund: $@" );
            }
            else
            {
                push( @err,
                      "Grund: Die Mail entspricht nicht der MIME-Syntax!" );
            }
            unless (close(MAIL))
            {
                push( @err,
                      "Kann Datei '$file' nicht schliessen!",
                      "Grund: $!" );
            }
            &writelog( $file );
            next;
        }
        unless (close(MAIL))
        {
            @err = ( "Kann Datei '$file' nicht schliessen!", "Grund: $!" );
            &writelog( $file );
            next;
        }
    }
}

my($self);

$self = $0;
$self =~ s!^.*/!!;

unless (@ARGV)
{
    die "Usage: $self <tempdir> <filename> [<filename> ...]\n";
}

&open_mime(@ARGV);

exit;

__END__

